CompleteRequestByOtherErrorParams class

Parameters for completing a request with a non-Dio error.

Constructors

CompleteRequestByOtherErrorParams({required dynamic key, required String response, required String message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → dynamic
final
message String
final
response String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited