CompleteRequestParams class

Parameters for completing a request without depending on Response.

Constructors

CompleteRequestParams({required RequestOptions key, dynamic responseData, Map<String, List<String>>? responseHeader, int? requestContentLength, int? responseContentLength, int? httpCode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
httpCode int?
final
key → RequestOptions
final
requestContentLength int?
final
responseContentLength int?
final
responseData → dynamic
final
responseHeader Map<String, List<String>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited