addMapRequestOption method
Adds a request model to the map for the given key.
Implementation
void addMapRequestOption(dynamic key, RequestModel model) {
if (!isLogEnabled) return;
mapKeys[key] = model;
}
Adds a request model to the map for the given key.
void addMapRequestOption(dynamic key, RequestModel model) {
if (!isLogEnabled) return;
mapKeys[key] = model;
}