DevUILoggerAbstract class

Abstract base class for API Logger implementations.

Contains core properties such as saveManager, navigatorKey, isLogEnabled, isLogCurl, and the list of models.

Implementers

Constructors

DevUILoggerAbstract()

Properties

apiLogConfig ApiLogConfig
Which API log details are captured and logged.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLogEnabled bool
Whether logging is enabled.
getter/setter pair
models List<BaseModel>
The list of models tracked by the logger.
getter/setter pair
The navigator key for navigation operations.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveManager SaveManager
The save manager for persistent storage.
getter/setter pair

Methods

getNextId() int
Get the next unique ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited