init method
void
init()
Initializes the provider by setting up listeners and loading initial data.
This method registers the provider as a listener to the DevUILogger and loads the initial list of models.
Implementation
void init() {
DevUILogger.instance.addListener(handleUpdateLog);
root = DevUILogger.instance.models;
filter();
}