CompleteRequestByOtherErrorParams class
Parameters for completing a request with a non-Dio error.
Constructors
- CompleteRequestByOtherErrorParams({required dynamic key, required String response, required String message})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited